/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { S3Key } from '../models/S3Key';
import type { User } from '../models/User';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class UserService {

    /**
     * Get the logged in user
     * Return the user associated with the used JWT.
     *
     * @returns User Successful Response
     * @throws ApiError
     */
    public static userGetLoggedInUser(): CancelablePromise<User> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/users/me',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
            },
        });
    }

    /**
     * Get a user by its username
     * Return the user with the specific username. A user can only view himself.
     *
     * @param username Username of a user
     * @returns User Successful Response
     * @throws ApiError
     */
    public static userGetUser(
        username: string,
    ): CancelablePromise<User> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/users/{username}',
            path: {
                'username': username,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get the S3 Access keys from a user
     * Get all the S3 Access keys for a specific user.
     *
     * @param username Username of a user
     * @returns S3Key Successful Response
     * @throws ApiError
     */
    public static keyGetUserKeys(
        username: string,
    ): CancelablePromise<Array<S3Key>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/users/{username}/keys',
            path: {
                'username': username,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Create a Access key for a user
     * Create a S3 Access key for a specific user.
     *
     * @param username Username of a user
     * @returns S3Key Successful Response
     * @throws ApiError
     */
    public static keyCreateUserKey(
        username: string,
    ): CancelablePromise<S3Key> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/users/{username}/keys',
            path: {
                'username': username,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get a specific S3 Access key from a user
     * Get a specific S3 Access Key for a specific user.
     *
     * @param accessId ID of the S3 access key
     * @param username Username of a user
     * @returns S3Key Successful Response
     * @throws ApiError
     */
    public static keyGetUserKey(
        accessId: string,
        username: string,
    ): CancelablePromise<S3Key> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/users/{username}/keys/{access_id}',
            path: {
                'access_id': accessId,
                'username': username,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Delete a specific S3 Access key from a user
     * Delete a specific S3 Access key for a specific user.
     *
     * @param accessId ID of the S3 access key
     * @param username Username of a user
     * @returns void
     * @throws ApiError
     */
    public static keyDeleteUserKey(
        accessId: string,
        username: string,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/users/{username}/keys/{access_id}',
            path: {
                'access_id': accessId,
                'username': username,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
